summaryrefslogtreecommitdiffstats
path: root/kexi/main/startup/KexiStartupDialogTemplatesPage.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/main/startup/KexiStartupDialogTemplatesPage.cpp')
-rw-r--r--kexi/main/startup/KexiStartupDialogTemplatesPage.cpp56
1 files changed, 28 insertions, 28 deletions
diff --git a/kexi/main/startup/KexiStartupDialogTemplatesPage.cpp b/kexi/main/startup/KexiStartupDialogTemplatesPage.cpp
index 3a64fbace..52fe08707 100644
--- a/kexi/main/startup/KexiStartupDialogTemplatesPage.cpp
+++ b/kexi/main/startup/KexiStartupDialogTemplatesPage.cpp
@@ -26,7 +26,7 @@
#include "KexiConnSelector.h"
#include "KexiConnSelectorBase.h"
-#include <qheader.h>
+#include <tqheader.h>
#include <kdebug.h>
#include <kiconloader.h>
@@ -36,14 +36,14 @@
#define KEXI_STARTUP_SHOW_RECENT
#endif
-/*QPixmap createIcon()
+/*TQPixmap createIcon()
{
}*/
/*QString createText(const QString& name, const QString& description)
{
- QString txt = "<H2>" + name + "</H2>";
+ TQString txt = "<H2>" + name + "</H2>";
if (description.isEmpty())
return name + description
}*/
@@ -52,10 +52,10 @@
class TemplateItem : public KListViewItem
{
public:
- TemplateItem(QListView* parent, const QString& aFilename,
- const QString& name, const QString& description, const QPixmap& icon,
- const QValueList<KexiProjectData::ObjectInfo>& aAutoopenObjects)
- : KListViewItem(parent, name + "\n" + description)
+ TemplateItem(TQListView* tqparent, const TQString& aFilename,
+ const TQString& name, const TQString& description, const TQPixmap& icon,
+ const TQValueList<KexiProjectData::ObjectInfo>& aAutoopenObjects)
+ : KListViewItem(tqparent, name + "\n" + description)
, autoopenObjects(aAutoopenObjects)
, filename(aFilename)
{
@@ -63,22 +63,22 @@ class TemplateItem : public KListViewItem
}
~TemplateItem() {}
- QValueList<KexiProjectData::ObjectInfo> autoopenObjects;
- QString filename;
+ TQValueList<KexiProjectData::ObjectInfo> autoopenObjects;
+ TQString filename;
};
//-----------------------
-KexiStartupDialogTemplatesPage::KexiStartupDialogTemplatesPage( QWidget * parent )
- : KListView(parent, "KexiStartupDialogTemplatesPage")
+KexiStartupDialogTemplatesPage::KexiStartupDialogTemplatesPage( TQWidget * tqparent )
+ : KListView(tqparent, "KexiStartupDialogTemplatesPage")
, m_popuplated(false)
{
- addColumn(QString::null);
+ addColumn(TQString());
header()->hide();
setColumnWidthMode(0, Maximum);
setResizeMode(LastColumn);
setItemMargin(6);
- connect(this,SIGNAL(executed(QListViewItem*)), this, SLOT(slotExecuted(QListViewItem*)));
+ connect(this,TQT_SIGNAL(executed(TQListViewItem*)), this, TQT_SLOT(slotExecuted(TQListViewItem*)));
}
KexiStartupDialogTemplatesPage::~KexiStartupDialogTemplatesPage()
@@ -91,7 +91,7 @@ void KexiStartupDialogTemplatesPage::populate()
return;
m_popuplated = true;
KexiTemplateInfo::List list = KexiTemplateLoader::loadListInfo();
- foreach( QValueList<KexiTemplateInfo>::ConstIterator, it, list ) {
+ foreach( TQValueList<KexiTemplateInfo>::ConstIterator, it, list ) {
new TemplateItem(this, (*it).filename, (*it).name,
(*it).description, (*it).icon, (*it).autoopenObjects);
}
@@ -104,12 +104,12 @@ void KexiStartupDialogTemplatesPage::populate()
// info = new KTextBrowser(this,"info");
// setResizeMode(templates,KeepSize);
// setResizeMode(info,KeepSize);
-// connect(templates,SIGNAL(selectionChanged(QIconViewItem*)),this,SLOT(itemClicked(QIconViewItem*)));
+// connect(templates,TQT_SIGNAL(selectionChanged(TQIconViewItem*)),this,TQT_SLOT(itemClicked(TQIconViewItem*)));
}
/*
-void TemplatesPage::addItem(const QString& key, const QString& name,
- const QString& description, const QPixmap& icon)
+void TemplatesPage::addItem(const TQString& key, const TQString& name,
+ const TQString& description, const TQPixmap& icon)
{
TemplateItem *item = new TemplateItem(templates, name, icon);
item->key=key;
@@ -117,35 +117,35 @@ void TemplatesPage::addItem(const QString& key, const QString& name,
item->description=description;
}
-void TemplatesPage::itemClicked(QIconViewItem *item) {
+void TemplatesPage::itemClicked(TQIconViewItem *item) {
if (!item) {
info->setText("");
return;
}
- QString t = QString("<h2>%1</h2><p>%2</p>")
- .arg(static_cast<TemplateItem*>(item)->name)
- .arg(static_cast<TemplateItem*>(item)->description);
+ TQString t = TQString("<h2>%1</h2><p>%2</p>")
+ .tqarg(static_cast<TemplateItem*>(item)->name)
+ .tqarg(static_cast<TemplateItem*>(item)->description);
#ifndef DB_TEMPLATES
- t += QString("<p>") + i18n("We are sorry, templates are not yet available.") +"</p>";
+ t += TQString("<p>") + i18n("We are sorry, templates are not yet available.") +"</p>";
#endif
info->setText( t );
}*/
-QString KexiStartupDialogTemplatesPage::selectedFileName() const
+TQString KexiStartupDialogTemplatesPage::selectedFileName() const
{
TemplateItem* templateItem = static_cast<TemplateItem*>(selectedItem());
- return templateItem ? templateItem->filename : QString::null;
+ return templateItem ? templateItem->filename : TQString();
}
-QValueList<KexiProjectData::ObjectInfo>
+TQValueList<KexiProjectData::ObjectInfo>
KexiStartupDialogTemplatesPage::autoopenObjectsForSelectedTemplate() const
{
TemplateItem* templateItem = static_cast<TemplateItem*>(selectedItem());
- return templateItem ? templateItem->autoopenObjects : QValueList<KexiProjectData::ObjectInfo>();
+ return templateItem ? templateItem->autoopenObjects : TQValueList<KexiProjectData::ObjectInfo>();
}
-void KexiStartupDialogTemplatesPage::slotExecuted(QListViewItem* item)
+void KexiStartupDialogTemplatesPage::slotExecuted(TQListViewItem* item)
{
TemplateItem* templateItem = static_cast<TemplateItem*>(item);
if (!templateItem)
@@ -36,14 +36,14 @@
{
}*/
-/*QString createText(const QString& name, const QString& description)
+/*TQString createText(const TQString& name, const TQString& description)
{